/*
 * Test directory reading operations.
 *
 * Copyright (C) 2020, 2021, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/re/env.h>
#include <l4/sys/err.h>

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include <fsclient/client.h>
#include <systypes/fcntl.h>



int main(int argc, char *argv[])
{
  if (argc < 2)
  {
    printf("Need a directory name.\n");
    return 1;
  }

  char *filename = argv[1];

  printf("Opening %s...\n", filename);

  file_t *reader = client_opendir(filename);

  if (reader == NULL)
  {
    printf("Could not read from directory.\n");
    return 1;
  }

  printf("Reading...\n");

  struct dirent *dirent;

  while ((dirent = client_readdir(reader)) != NULL)
  {
    printf("> %s\n", dirent->d_name);
    free(dirent);
  }

  printf("Directory shown.\n");

  /* Open again, reading a single entry only. */

  reader = client_opendir(filename);

  if (reader == NULL)
  {
    printf("Could not read from directory.\n");
    return 1;
  }

  dirent = client_readdir(reader);

  if (dirent != NULL)
  {
    printf("> %s\n", dirent->d_name);
    free(dirent);
  }

  printf("Entry shown.\n");

  return 0;
}

// vim: tabstop=2 expandtab shiftwidth=2
